@@ -43,48 +43,49 @@ def test_sign_agreement(publisher_instance, consumer_instance, registered_ddo):
     # Verify condition types (condition contracts)
     agreement_values = keeper.agreement_manager.get_agreement(agreement_id)
     assert agreement_values.did == asset_id, ''
-    cond_types = keeper.escrow_access_secretstore_template.get_condition_types()
+    cond_types = keeper.access_template.get_condition_types()
     for i, cond_id in enumerate(agreement_values.condition_ids):
         cond = keeper.condition_manager.get_condition(cond_id)
         assert cond.type_ref == cond_types[i]
 
     access_cond_id, lock_cond_id, escrow_cond_id = agreement_values.condition_ids
 
-    # Fulfill lock_reward_condition is done automatically when create agreement is done correctly
+    # Fulfill lock_payment_condition is done automatically when create agreement is done correctly
     assert 2 == keeper.condition_manager.get_condition_state(lock_cond_id), ''
     assert 1 == keeper.condition_manager.get_condition_state(access_cond_id), ''
     assert 1 == keeper.condition_manager.get_condition_state(escrow_cond_id), ''
 
-    # Fulfill access_secret_store_condition
-    tx_hash = keeper.access_secret_store_condition.fulfill(
+    # Fulfill access_condition
+    tx_hash = keeper.access_condition.fulfill(
         agreement_id, asset_id, consumer_acc.address, publisher_acc
     )
-    keeper.access_secret_store_condition.get_tx_receipt(tx_hash)
+    keeper.access_condition.get_tx_receipt(tx_hash)
     assert 2 == keeper.condition_manager.get_condition_state(access_cond_id), ''
-    event = keeper.access_secret_store_condition.subscribe_condition_fulfilled(
+    event = keeper.access_condition.subscribe_condition_fulfilled(
         agreement_id,
         10,
-        log_event(keeper.access_secret_store_condition.FULFILLED_EVENT),
+        log_event(keeper.access_condition.FULFILLED_EVENT),
         (),
         wait=True
     )
     assert event, 'no event for AccessSecretStoreCondition.Fulfilled'
 
-    # Fulfill escrow_reward_condition
-    amounts = list(map(int, service_agreement.get_param_value_by_name('_amounts')))
-    receivers = to_checksum_addresses(service_agreement.get_param_value_by_name('_receivers'))
+    # Fulfill escrow_payment_condition
 
-    tx_hash = keeper.escrow_reward_condition.fulfill(
-        agreement_id, amounts, receivers,
-        publisher_acc.address, lock_cond_id,
+    amounts = service_agreement.get_amounts_int()
+    receivers = service_agreement.get_receivers()
+
+    tx_hash = keeper.escrow_payment_condition.fulfill(
+        agreement_id, asset_id, amounts, receivers,
+        keeper.escrow_payment_condition.address, lock_cond_id,
         access_cond_id, publisher_acc
     )
-    keeper.escrow_reward_condition.get_tx_receipt(tx_hash)
+    keeper.escrow_payment_condition.get_tx_receipt(tx_hash)
     assert 2 == keeper.condition_manager.get_condition_state(escrow_cond_id), ''
-    event = keeper.escrow_reward_condition.subscribe_condition_fulfilled(
+    event = keeper.escrow_payment_condition.subscribe_condition_fulfilled(
         agreement_id,
         10,
-        log_event(keeper.escrow_reward_condition.FULFILLED_EVENT),
+        log_event(keeper.escrow_payment_condition.FULFILLED_EVENT),
         (),
         wait=True
     )
@@ -93,7 +94,7 @@ def test_sign_agreement(publisher_instance, consumer_instance, registered_ddo):
 
 
 # @pytest.mark.skip(reason="Failing some times with actions")
-def test_agreement_status(setup_agreements_enviroment, agreements):
+def test_agreement_status(setup_agreements_environment, agreements):
     (
         keeper,
         publisher_acc,
@@ -104,9 +105,9 @@ def test_agreement_status(setup_agreements_enviroment, agreements):
         service_agreement,
         (lock_cond_id, access_cond_id, escrow_cond_id),
 
-    ) = setup_agreements_enviroment
+    ) = setup_agreements_environment
 
-    success = keeper.escrow_access_secretstore_template.create_agreement(
+    success = keeper.access_template.create_agreement(
         agreement_id,
         asset_id,
         [access_cond_id, lock_cond_id, escrow_cond_id],
@@ -117,10 +118,10 @@ def test_agreement_status(setup_agreements_enviroment, agreements):
     )
     print('create agreement: ', success)
     assert success, f'createAgreement failed {success}'
-    event = keeper.escrow_access_secretstore_template.subscribe_agreement_created(
+    event = keeper.access_template.subscribe_agreement_created(
         agreement_id,
         10,
-        log_event(keeper.escrow_access_secretstore_template.AGREEMENT_CREATED_EVENT),
+        log_event(keeper.access_template.AGREEMENT_CREATED_EVENT),
         (),
         wait=True
     )
@@ -132,12 +133,15 @@ def test_agreement_status(setup_agreements_enviroment, agreements):
                                                               }
                                                }
 
-    agreements.conditions.lock_reward(agreement_id, price, consumer_acc)
+    amounts = service_agreement.get_amounts_int()
+    receivers = service_agreement.get_receivers()
 
-    event = keeper.lock_reward_condition.subscribe_condition_fulfilled(
+    agreements.conditions.lock_payment(agreement_id, asset_id, amounts, receivers, consumer_acc)
+
+    event = keeper.lock_payment_condition.subscribe_condition_fulfilled(
         agreement_id,
         10,
-        log_event(keeper.lock_reward_condition.FULFILLED_EVENT),
+        log_event(keeper.lock_payment_condition.FULFILLED_EVENT),
         (),
         wait=True
     )
@@ -148,13 +152,13 @@ def test_agreement_status(setup_agreements_enviroment, agreements):
                                                               "escrowReward": 1
                                                               }
                                                }
-    tx_hash = keeper.access_secret_store_condition.fulfill(
+    tx_hash = keeper.access_condition.fulfill(
         agreement_id, asset_id, consumer_acc.address, publisher_acc)
-    keeper.access_secret_store_condition.get_tx_receipt(tx_hash)
-    event = keeper.access_secret_store_condition.subscribe_condition_fulfilled(
+    keeper.access_condition.get_tx_receipt(tx_hash)
+    event = keeper.access_condition.subscribe_condition_fulfilled(
         agreement_id,
         20,
-        log_event(keeper.access_secret_store_condition.FULFILLED_EVENT),
+        log_event(keeper.access_condition.FULFILLED_EVENT),
         (),
         wait=True
     )
@@ -166,19 +170,16 @@ def test_agreement_status(setup_agreements_enviroment, agreements):
                                                               }
                                                }
 
-    amounts = list(map(int, service_agreement.get_param_value_by_name('_amounts')))
-    receivers = to_checksum_addresses(service_agreement.get_param_value_by_name('_receivers'))
-
-    tx_hash = keeper.escrow_reward_condition.fulfill(
-        agreement_id, amounts, to_checksum_addresses(receivers),
-        publisher_acc.address, lock_cond_id,
+    tx_hash = keeper.escrow_payment_condition.fulfill(
+        agreement_id, asset_id, amounts, receivers,
+        keeper.escrow_payment_condition.address, lock_cond_id,
         access_cond_id, publisher_acc
     )
-    keeper.escrow_reward_condition.get_tx_receipt(tx_hash)
-    event = keeper.escrow_reward_condition.subscribe_condition_fulfilled(
+    keeper.escrow_payment_condition.get_tx_receipt(tx_hash)
+    event = keeper.escrow_payment_condition.subscribe_condition_fulfilled(
         agreement_id,
         10,
-        log_event(keeper.escrow_reward_condition.FULFILLED_EVENT),
+        log_event(keeper.escrow_payment_condition.FULFILLED_EVENT),
         (),
         wait=True
     )
